@@ -2,8 +2,8 @@ arrange_lambda<- function(x)
 {
   Dim <- dim( x )[1]
   Q   <- dim( x )[2]
-  y <- rep( NA, Dim*Q )
-  index <- matrix(NA, nrow = Dim*Q, ncol = 2)
+  y   <- rep( 0, Dim*Q )
+  index <- matrix(0, nrow = Dim*Q, ncol = 2)
   k <- 1
   for(i in 1:Dim)
   {
