@@ -1,8 +1,8 @@
 arrange_sigma <- function(x)
 {
   Dim <- length( x[1, ] )
-  y <- rep( NA, Dim*(Dim + 1)/2 )
-  index <- matrix(NA, nrow = Dim*(Dim + 1)/2, ncol = 2)
+  y <- rep( 0, Dim*(Dim + 1)/2 )
+  index <- matrix(0, nrow = Dim*(Dim + 1)/2, ncol = 2)
   k <- 1
   for(i in 1:Dim)
   {
